@@ -1,8 +1,9 @@
 use std::time::SystemTime;
 
-#[cfg(not(feature = "sqlite"))]
+use crate::args::Args;
+#[cfg(not(feature = "sql"))]
 use crate::peer_db::basic::{Error, PeerDB};
-#[cfg(feature = "sqlite")]
+#[cfg(feature = "sql")]
 use crate::peer_db::sqlite::{Error, PeerDB};
 use crate::peer_db::PeerDatabase;
 
@@ -12,9 +13,9 @@ pub struct SharedState {
 }
 
 impl SharedState {
-  pub fn new() -> SharedState {
+  pub fn new(args: &Args) -> SharedState {
     SharedState {
-      peer_db:    Box::new(PeerDB::new().unwrap()),
+      peer_db:    Box::new(PeerDB::new(&args).unwrap()),
       start_time: SystemTime::now(),
     }
   }
